<?php
namespace Teknisa\MAN\Services;

use Teknisa\MAN\Factories\FiliaisRepository;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Utilities;

class FiliaisService {
    const INSERE_FILIAL = 1;
    const FILIAL_INATIVA = 2;
    const FILIAL_ATIVA = 3;
    const INSERE_LOJA = 4;
    const LOJA_INATIVA = 5;
    const LOJA_ATIVA = 6;
    /**
     * @var FiliaisRepository
     */
    protected $filiaisRepository;

    public function __construct(FiliaisRepository $filiaisRepository, \Doctrine\ORM\EntityManager $entityManager) {
        $this->filiaisRepository = $filiaisRepository;
        $this->entityManager = $entityManager;
    }

    /**
     * @return int
     */
    public function getNextId() {
        $idRow = $this->filiaisRepository->getMaxId();
        $id = $idRow[0]['MAX_ID'];
        return !is_null($id) ? ++$id : 1;
    }


    public function getNextId1() {
        $idRow = $this->filiaisRepository->getMaxId1();
        $id = $idRow[0]['MAX_ID'];
        return !is_null($id) ? ++$id : 1;
    }

    public function checaExistenciaConfig($cdfilial, $cdloja, $cdcaixa, $nrorg) {
        if($cdloja == null)
            $retorno = $this->filiaisRepository->checaExistenciaConfig($cdfilial, $nrorg);
        else if($cdcaixa == null) {
            $retorno = $this->filiaisRepository->checaExistenciaConfigLoja($cdfilial, $cdloja, $nrorg);
        }
        else
            $retorno = $this->filiaisRepository->checaExistenciaConfigCaixa($cdfilial, $cdloja, $cdcaixa, $nrorg);
        
        if($retorno != null)
            $isConfigDefine = true;
        else
            $isConfigDefine = false;

        return $isConfigDefine;
    }

    public function checaConfigByFilial($cdfilial, $nrconfiguracao, $nrorg) {
        $retorno = $this->filiaisRepository->checaConfigByFilial($cdfilial, $nrconfiguracao, $nrorg);
        if($retorno != null)
            return true;
        return false;
    }

    public function checaConfigByFilialLoja($cdfilial, $cdloja, $nrconfiguracao, $nrorg) {
        
        $retorno = $this->filiaisRepository->checaConfigByFilialLoja($cdfilial, $cdloja, $nrconfiguracao, $nrorg);
        if($retorno != null)
            return true;
        return false;
    }

    public function deletar(DTO\Request\DataSet $request){
        foreach($request->getDataSet()->getRows() as &$row) {
            $params = array(
                "CDFILIAL"=>$row['CDFILIAL'],
                "CDLOJA"=>$row['CDLOJA'],
                "CDCAIXA"=>$row['CDCAIXA'],
                "NRORG"=>$row['NRORG']
            );
            $connection = $this->entityManager->getConnection();
            $query = $connection->prepare(Utilities\Query::DELETE_VND_RELESTRTURACONFIGURACAO);
            $query->execute($params);
        }
    }

    public function getLojasByFilial($cdtabprec, $cdfilialtabprec, $cdfilial, $nrorg){
        $stmt = $this->entityManager->getConnection()->prepare(Utilities\Query::GET_VND_RELESTRUTURATABEPRECO);
        $stmt->execute(array('CDTABPREC' => $cdtabprec,
                             'CDFILIALTABPREC' => $cdfilialtabprec,
                             'CDFILIAL' => $cdfilial,
                             'NRORG' => $nrorg));
        $resp = $stmt->fetchAll();
        if(empty($resp)){
            return 1;
        } else {
            return $resp;
        }
    }

    public function validaFilial($cdtabprec, $cdfilialtabprec, $cdfilial, $nrorg){
        $stmt = $this->entityManager->getConnection()->prepare(Utilities\Query::GET_IDATIVO_VND_RELESTRUTURATABEPRECO);
        $stmt->execute(array('CDTABPREC' => $cdtabprec,
                             'CDFILIALTABPREC' => $cdfilialtabprec,
                             'CDFILIAL' => $cdfilial,
                             'NRORG' => $nrorg));
        $resp = $stmt->fetchAll();
        $id = null;
        if(empty($resp)){
            $retorno = self::INSERE_FILIAL;
        } else{
            $retorno = $resp[0]['IDATIVO'] == 'S' ? self::FILIAL_ATIVA : self::FILIAL_INATIVA;
            $id = $resp[0]['NRRELESTRUTURATABEPRECO'];
        }
        return array('valida'=>$retorno,
                     'NRRELESTRUTURATABEPRECO' => $id);
    }

    public function validaLoja($cdtabprec, $cdfilialtabprec, $cdfilial, $cdloja, $nrorg){
        $stmt = $this->entityManager->getConnection()->prepare(Utilities\Query::GET_VND_RELESTRUTURATABEPRECO_VALIDALOJA);
        $stmt->execute(array('CDTABPREC' => $cdtabprec,
                             'CDFILIALTABPREC' => $cdfilialtabprec,
                             'CDFILIAL' => $cdfilial,
                             'CDLOJA' => $cdloja,
                             'NRORG' => $nrorg));
        $resp = $stmt->fetchAll();
        $id = null;
        if(empty($resp)) {
            $retorno = self::INSERE_LOJA;
        } else {
            $retorno = $resp[0]['IDATIVO'] == 'S' ? self::LOJA_ATIVA : self::LOJA_INATIVA;
            $id = $resp[0]['NRRELESTRUTURATABEPRECO'];
        }
        return array('valida'=>$retorno,
                     'NRRELESTRUTURATABEPRECO' => $id);
    }
}